.. Morf Dict documentation master file, created by
   sphinx-quickstart on Mon Oct 20 18:58:05 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Morf Dict
=========

``MorfDict`` is a dict like object, which convers data late on the fly. With
StringDict and PathDict it can help for example with multi level settings.

Overall
=======

.. toctree::
   :maxdepth: 3

   intro
   tutorial
   api/index


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

